pub enum Preference<'a, F>{
Median,
List(&'a Array1<F>),
Value(F),
}Expand description
Preference is the value representing the degree to which a data point will act as its own exemplar, with lower (more negative) values yielding fewer clusters.
- Median: Use median similarity value as preference
- List: Use provided preference list
- Value: Assign all members the same preference value
Variants
Median
Use the median pairwise similarity as the preference
List(&'a Array1<F>)
Use a list of preferences, one per input
Value(F)
Use a single value as the preference for all inputs